@@ -36,8 +36,8 @@ public class Gnome
 
     static
     {
-        System.loadLibrary ("gtkjava2.5");
-        System.loadLibrary ("gnomejava2.9");
+		System.loadLibrary ("gtkjni-2.6");
+        System.loadLibrary ("gnomejni-2.9");
     }
 
     native static final protected Handle gnome_master_client ();
