@@ -9,7 +9,7 @@
 
 #include <jni.h>
 #include <libgnomecanvas/libgnomecanvas.h>
-#include "jg_jnu.h"
+#include <jg_jnu.h>
 
 #ifdef __cplusplus
 extern "C" 
