@@ -8,29 +8,18 @@
  */
 
 #include <jni.h>
-#include <sys/types.h>
 #include <gnome.h>
+#include <jg_jnu.h>
 
 #ifndef _Included_org_gnu_gnome_PasswordDialog
 #define _Included_org_gnu_gnome_PasswordDialog
 #ifdef __cplusplus
 extern "C" {
 #endif
-/* Inaccessible static: evtMap */
-/* Inaccessible static: class_000240 */
-/* Inaccessible static: class_000241 */
-/* Inaccessible static: class_000242 */
-/* Inaccessible static: class_000243 */
-/* Inaccessible static: class_000244 */
-/* Inaccessible static: class_000245 */
-/* Inaccessible static: evtMap */
-/* Inaccessible static: class_000240 */
-/* Inaccessible static: evtMap */
-/* Inaccessible static: class_000240 */
+
 /*
  * Class:     org_gnu_gnome_PasswordDialog
  * Method:    gnome_password_dialog_get_type
- * Signature: ()I
  */
 JNIEXPORT jint JNICALL Java_org_gnu_gnome_PasswordDialog_gnome_1password_1dialog_1get_1type
   (JNIEnv *env, jclass cls)
@@ -41,9 +30,8 @@ JNIEXPORT jint JNICALL Java_org_gnu_gnome_PasswordDialog_gnome_1password_1dialog
 /*
  * Class:     org_gnu_gnome_PasswordDialog
  * Method:    gnome_password_dialog_new
- * Signature: (Ljava/lang/String;Ljava/lang/String;Ljava/lang/String;Ljava/lang/String;Z)I
  */
-JNIEXPORT jint JNICALL Java_org_gnu_gnome_PasswordDialog_gnome_1password_1dialog_1new
+JNIEXPORT jobject JNICALL Java_org_gnu_gnome_PasswordDialog_gnome_1password_1dialog_1new
   (JNIEnv *env, jclass cls, jstring title, jstring message, jstring username, jstring password, jboolean readonly)
 {
 	const char *t = title ? (*env)->GetStringUTFChars(env, title, NULL) : NULL;
@@ -59,111 +47,112 @@ JNIEXPORT jint JNICALL Java_org_gnu_gnome_PasswordDialog_gnome_1password_1dialog
 		(*env)->ReleaseStringUTFChars(env, username, u);
 	if (p)
 		(*env)->ReleaseStringUTFChars(env, password, p);
-	return (jint)ret;
+	return getHandleFromPointer(env, ret);
 }
 
 /*
  * Class:     org_gnu_gnome_PasswordDialog
  * Method:    gnome_password_dialog_run_and_block
- * Signature: (I)Z
  */
 JNIEXPORT jboolean JNICALL Java_org_gnu_gnome_PasswordDialog_gnome_1password_1dialog_1run_1and_1block
-  (JNIEnv *env, jclass cls, jint dialog)
+  (JNIEnv *env, jclass cls, jobject dialog)
 {
-	return (jboolean)gnome_password_dialog_run_and_block((GnomePasswordDialog*)dialog);
+	GnomePasswordDialog* dialog_g = (GnomePasswordDialog*)getPointerFromHandle(env, dialog);
+	return (jboolean)gnome_password_dialog_run_and_block(dialog_g);
 }
 
 /*
  * Class:     org_gnu_gnome_PasswordDialog
  * Method:    gnome_password_dialog_set_username
- * Signature: (ILjava/lang/String;)V
  */
 JNIEXPORT void JNICALL Java_org_gnu_gnome_PasswordDialog_gnome_1password_1dialog_1set_1username
-  (JNIEnv *env, jclass cls, jint dialog, jstring username)
+  (JNIEnv *env, jclass cls, jobject dialog, jstring username)
 {
-		const char *u = (*env)->GetStringUTFChars(env, username, NULL);
-		gnome_password_dialog_set_username((GnomePasswordDialog*)dialog, u);
-		(*env)->ReleaseStringUTFChars(env, username, u);
+	GnomePasswordDialog* dialog_g = (GnomePasswordDialog*)getPointerFromHandle(env, dialog);
+	const char *u = (*env)->GetStringUTFChars(env, username, NULL);
+	gnome_password_dialog_set_username(dialog_g, u);
+	(*env)->ReleaseStringUTFChars(env, username, u);
 }
 
 /*
  * Class:     org_gnu_gnome_PasswordDialog
  * Method:    gnome_password_dialog_set_password
- * Signature: (ILjava/lang/String;)V
  */
 JNIEXPORT void JNICALL Java_org_gnu_gnome_PasswordDialog_gnome_1password_1dialog_1set_1password
-  (JNIEnv *env, jclass cls, jint dialog, jstring password)
+  (JNIEnv *env, jclass cls, jobject dialog, jstring password)
 {
-		const char *p = (*env)->GetStringUTFChars(env, password, NULL);
-		gnome_password_dialog_set_password((GnomePasswordDialog*)dialog, p);
-		(*env)->ReleaseStringUTFChars(env, password, p);
+	GnomePasswordDialog* dialog_g = (GnomePasswordDialog*)getPointerFromHandle(env, dialog);
+	const char *p = (*env)->GetStringUTFChars(env, password, NULL);
+	gnome_password_dialog_set_password(dialog_g, p);
+	(*env)->ReleaseStringUTFChars(env, password, p);
 }
 
 /*
  * Class:     org_gnu_gnome_PasswordDialog
  * Method:    gnome_password_dialog_set_readonly_username
- * Signature: (IZ)V
  */
 JNIEXPORT void JNICALL Java_org_gnu_gnome_PasswordDialog_gnome_1password_1dialog_1set_1readonly_1username
-  (JNIEnv *env, jclass cls, jint dialog, jboolean readonly)
+  (JNIEnv *env, jclass cls, jobject dialog, jboolean readonly)
 {
-	gnome_password_dialog_set_readonly_username((GnomePasswordDialog*)dialog, (gboolean)readonly);
+	GnomePasswordDialog* dialog_g = (GnomePasswordDialog*)getPointerFromHandle(env, dialog);
+	gnome_password_dialog_set_readonly_username(dialog_g, (gboolean)readonly);
 }
 
 /*
  * Class:     org_gnu_gnome_PasswordDialog
  * Method:    gnome_password_dialog_set_remember
- * Signature: (IZ)V
  */
 JNIEXPORT void JNICALL Java_org_gnu_gnome_PasswordDialog_gnome_1password_1dialog_1set_1remember
-  (JNIEnv *env, jclass cls, jint dialog, jboolean remember)
+  (JNIEnv *env, jclass cls, jobject dialog, jboolean remember)
 {
-	gnome_password_dialog_set_remember((GnomePasswordDialog*)dialog, (gboolean)remember);
+	GnomePasswordDialog* dialog_g = (GnomePasswordDialog*)getPointerFromHandle(env, dialog);
+	gnome_password_dialog_set_remember(dialog_g, (gboolean)remember);
 }
 
 /*
  * Class:     org_gnu_gnome_PasswordDialog  
- * * Method:    gnome_password_dialog_set_show_userpass_buttons
- * Signature: (IZ)V  */
+ * Method:    gnome_password_dialog_set_show_userpass_buttons
+ */
 JNIEXPORT void JNICALL Java_org_gnu_gnome_PasswordDialog_gnome_1password_1dialog_1set_1show_1userpass_1buttons
-  (JNIEnv *env, jclass cls, jint dialog, jboolean show)                                                                               
+  (JNIEnv *env, jclass cls, jobject dialog, jboolean show)                                                                               
 {
-	gnome_password_dialog_set_show_userpass_buttons((GnomePasswordDialog*)dialog, (gboolean)show);
+	GnomePasswordDialog* dialog_g = (GnomePasswordDialog*)getPointerFromHandle(env, dialog);
+	gnome_password_dialog_set_show_userpass_buttons(dialog_g, (gboolean)show);
 }
 
 /*
  * Class:     org_gnu_gnome_PasswordDialog
  * Method:    gnome_password_dialog_get_username
- * Signature: (I)Ljava/lang/String;
  */
 JNIEXPORT jstring JNICALL Java_org_gnu_gnome_PasswordDialog_gnome_1password_1dialog_1get_1username
-  (JNIEnv *env, jclass cls, jint dialog)
+  (JNIEnv *env, jclass cls, jobject dialog)
 {
-	char *username = gnome_password_dialog_get_username((GnomePasswordDialog*)dialog);
+	GnomePasswordDialog* dialog_g = (GnomePasswordDialog*)getPointerFromHandle(env, dialog);
+	char *username = gnome_password_dialog_get_username(dialog_g);
 	return (*env)->NewStringUTF(env, username);
 }
 
 /*
  * Class:     org_gnu_gnome_PasswordDialog
  * Method:    gnome_password_dialog_get_password
- * Signature: (I)Ljava/lang/String;
  */
 JNIEXPORT jstring JNICALL Java_org_gnu_gnome_PasswordDialog_gnome_1password_1dialog_1get_1password
-  (JNIEnv *env, jclass cls, jint dialog)
+  (JNIEnv *env, jclass cls, jobject dialog)
 {
-	char *password = gnome_password_dialog_get_password((GnomePasswordDialog*)dialog);
+	GnomePasswordDialog* dialog_g = (GnomePasswordDialog*)getPointerFromHandle(env, dialog);
+	char *password = gnome_password_dialog_get_password(dialog_g);
 	return (*env)->NewStringUTF(env, password);
 }
 
 /*
  * Class:     org_gnu_gnome_PasswordDialog
  * Method:    gnome_password_dialog_get_remember
- * Signature: (I)Z
  */
 JNIEXPORT jboolean JNICALL Java_org_gnu_gnome_PasswordDialog_gnome_1password_1dialog_1get_1remember
-  (JNIEnv *env, jclass cls, jint dialog)
+  (JNIEnv *env, jclass cls, jobject dialog)
 {
-	return (jboolean)gnome_password_dialog_get_remember((GnomePasswordDialog*)dialog);
+	GnomePasswordDialog* dialog_g = (GnomePasswordDialog*)getPointerFromHandle(env, dialog);
+	return (jboolean)gnome_password_dialog_get_remember(dialog_g);
 }
 
 #ifdef __cplusplus
